import com.urbancode.anthill3.AHPTool
import com.urbancode.anthill3.CommandHelper
import com.urbancode.plugin.cvsexport.CVSPassword

final def String CVSNT_REGISTRY_KEY = 'HKEY_CURRENT_USER\\Software\\Cvsnt\\cvspass'
final def workDir = new File('.').canonicalFile
final def ahpTool = new AHPTool()

def Map props = ahpTool.getStepProperties()

final def commandPath = props['integration/commandPath']
final def inlinePassword = Boolean.parseBoolean(props['integration/inlinePassword']?:'false')
final def updateRegistry = Boolean.parseBoolean(props['integration/updateRegistry']?:'false')
final def cvsRoot = props['integration/cvsRoot']
def String password = props['integration/password']
final def passwordScript = props['integration/passwordScript']
if (passwordScript) {
    password = passwordScript
}
final def modulePath = props['modulePath']
final def dirOffset = props['dirOffset']
final def revision = props['revision']

//------------------------------------------------------------------------------
// PREPARE WORKING DIRECTORY
//------------------------------------------------------------------------------
workDir.mkdirs()

//------------------------------------------------------------------------------
// CHECK EXECUTABLE
//------------------------------------------------------------------------------

def cvsExecutable = 'cvs'
if (commandPath) {
    cvsExecutable = new File(new File(commandPath), cvsExecutable).canonicalPath
}

//------------------------------------------------------------------------------
// UPDATE .cvspass file
//------------------------------------------------------------------------------

if (password) {
    if (inlinePassword) {
        println 'Updating CVSROOT with password'
        cvsRoot = CVSPassword.addPasswordToCvsRoot(cvsRoot, password)
    }
    else if (updateRegistry && (System.getProperty('os.name') =~ /(?i)windows/).find()) {
        println 'Updating Windows registry with password'
        def encodedPassword = CVSPassword.getEncodedPassword(password)
        def helper = new CommandHelper(workDir)
        try {
            helper.runCommand('Update Windows Registy',
                    ['reg', 'add', CVSNT_REGISTRY_KEY, '/v', cvsRoot, '/d', encodedPassword, '/f'])
        }
        catch (Exception e) {
            println 'Error updating windows registry with CVS password: ' + e.message
            System.exit 1
        }
    }
    else {
        println 'Updating .cvspass file'
        def antBuilder = new AntBuilder()
        antBuilder.cvspass(cvsroot: cvsRoot, 'password': password)
    }
}

//------------------------------------------------------------------------------
// RUN CVS EXPORT
//------------------------------------------------------------------------------
def command = [cvsExecutable, '-d', cvsRoot, 'export']

if (revision) {
    command << "-r$revision"
}

if (dirOffset) {
    command << '-d'
    command << dirOffset
}
	
command << modulePath

def helper = new CommandHelper(workDir)
try {
    helper.runCommand('Run CVS export', command)
}
catch (Exception e) {
    e.printStackTrace()
    System.exit 1
}

System.exit 0
